==> loginpanel-0.1.1.tar.gz: loginpanel/LoginPanelController.m <==
/* 
   LoginPanelController.m

   Controller class which handles all activity in the loginpanel.

   Copyright (C) 2000 Free Software Foundation, Inc.

   Author:  Gregory John Casamento <borgheron@yahoo.com>
   Date: 2000
   
   This file is part of GNUstep.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#import "LoginPanelController.h"
#import "LoginImageView.h"
#import "Authenticator.h"


@implementation LoginPanelController
- init
{
  [super init];
  authenticator = [[Authenticator alloc] init];
  defaults = [NSUserDefaults standardUserDefaults];
  return self;
}

- (void)applicationDidFinishLaunching: (NSNotification *)notification
{
  puts("Ordering front...");
  [window makeKeyAndOrderFront: self];
}

- (void)passwordEntered:(id)sender
{
  char *pwstring = 0;
  BOOL verified = NO;
  
  pwstring = (char *)[[passwordField stringValue] cString];
  printf("Password: %s\n", pwstring );
  printf("Verifying login...\n");
  [authenticator setUsername: [usernameField stringValue]];
  [authenticator setPassword: [passwordField stringValue]];
  verified = [authenticator isPasswordCorrect];
  if( verified )
    {
      puts("Proceed to login...");
      [self logUserIn];
    }
  else
    {
      puts("Verification failed...");
      [self rejectEntries];
    }
}

- (void)powerButton:(id)sender
{
  puts("Powering down...");
}

- (void)restartButton:(id)sender
{
  puts("Restarting computer...");
}

- (void)usernameEntered:(id)sender
{
  printf("Username: %s\n", [[usernameField stringValue] cString]);
  if( ![[usernameField stringValue] isEqualToString: [NSString string]] )
    {
      [passwordField becomeFirstResponder];
    }
  else
    {
      puts("Null usernames are illegal...");
      [self rejectEntries];
    }
}

- (void)awakeFromNib
{
  puts("The sleeper has awakened");
  [window initializeInterface];
}

- (void)rejectEntries
{
  [usernameField setStringValue: @""];
  [passwordField setStringValue: @""];
  [window waggle];
  [usernameField becomeFirstResponder];
}

- (void)logUserIn
{
  [window shrink];
  [window close];
  [self startUserSession];  // We will spend a great deal of time here!!
  [NSBundle loadNibNamed: @"NEXTSTEP_loginpanel"
	    owner: self];
}

- (void)startUserSession
{
  puts("La la la... user is doing what he/she has to do... done.");
  [authenticator switchUser];
  [authenticator setEnvironment];
  [authenticator executeCommand: @"loginscript" path: @"/usr/sbin"];
  puts("User is done...");
}

- (void)showInfo: (id)sender
{
  // load info panel
  if( infoPanel == nil )
    {
      if( ![NSBundle loadNibNamed: @"InfoPanel"
		     owner: self])
	{
	  puts("Problem loading info panel...");
	}
    }
  [infoPanel makeKeyAndOrderFront: self];
}
@end

==> loginpanel-0.1.2.tar.gz: loginpanel/LoginPanelController.m <==
/* 
   LoginPanelController.m

   Controller class which handles all activity in the loginpanel.

   Copyright (C) 2000 Free Software Foundation, Inc.

   Author:  Gregory John Casamento <borgheron@yahoo.com>
   Date: 2000
   
   This file is part of GNUstep.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#import "LoginPanelController.h"
#import "LoginImageView.h"

#ifdef GNUSTEP
#import <gscrypt/GSPam.h>
#endif

@implementation LoginPanelController
- init
{
  // Initialize the superclass.
  [super init];

  // Laziness is a terrible thing.... I am making the loginpanel
  // application pretend as though it is xdm so that I don't
  // have to write my own .conf file for PAM.   I will get around
  // to writing it once I get this working.
#ifdef GNUSTEP
  authenticator = [[GSPam alloc] initWithServiceName: @"xdm"];
#endif
  defaults = [NSUserDefaults standardUserDefaults];

  return self;
}

- (void)applicationDidFinishLaunching: (NSNotification *)notification
{
#ifdef DEBUG
  puts("Ordering front...");
#endif
  [window makeKeyAndOrderFront: self];
#ifdef GNUSTEP
  // [[NSApp iconWindow] close];
#endif
}

- (void)passwordEntered:(id)sender
{
  char *pwstring = 0;
  BOOL verified = NO;
  
  pwstring = (char *)[[passwordField stringValue] cString];
#ifdef DEBUG 
  printf("Password: %s\n", pwstring );
  printf("Verifying login...\n");
#endif
  if(![authenticator start]) 
    {
      NSLog(@"Failed to start PAM");
    }

#ifdef GNUSTEP
  [authenticator setUser: [usernameField stringValue]];
  [authenticator setPassword: [passwordField stringValue]];
  verified = [authenticator authenticateWithFlag: PAM_DISALLOW_NULL_AUTHTOK
			    silent: NO];
#endif

  if( verified )
    {
#ifdef DEBUG
      puts("Proceed to login...");
#endif
      [self logUserIn];
    }
  else
    {
#ifdef DEBUG
      puts("Verification failed...");
#endif
      [self rejectEntries];
    }

  if(![authenticator end]) 
    {
      NSLog(@"Failed to end PAM");
    }
}

- (void)powerButton:(id)sender
{
#ifdef DEBUG
  puts("Powering down...");
#endif
  if(system("/sbin/shutdown -g0")) NSLog(@"Problem shutting down");
}

- (void)restartButton:(id)sender
{
#ifdef DEBUG
  puts("Restarting computer...");
#endif
  if(system("/sbin/reboot")) NSLog(@"Problem rebooting system");
}

- (void)usernameEntered:(id)sender
{
#ifdef DEBUG
  printf("Username: %s\n", [[usernameField stringValue] cString]);
#endif
  if( ![[usernameField stringValue] isEqualToString: [NSString string]] )
    {
      [passwordField becomeFirstResponder];
    }
  else
    {
#ifdef DEBUG
      puts("Null usernames are illegal...");
#endif
      [self rejectEntries];
    }
}

- (void)awakeFromNib
{
#ifdef DEBUG
  puts("The sleeper has awakened");
#endif
  [window initializeInterface];
}

- (void)rejectEntries
{
  [usernameField setStringValue: @""];
  [passwordField setStringValue: @""];
  [window waggle];
  [usernameField becomeFirstResponder];
}

- (void)logUserIn
{
  [window shrink];
  [window close];
#ifdef GNUSTEP
  [authenticator openSessionSilently: NO];  // We will spend a great deal of time here!!
#endif
  [NSBundle loadNibNamed: @"NEXTSTEP_loginpanel"
	    owner: self];
}

- (void)showInfo: (id)sender
{
  // load info panel
  if( infoPanel == nil )
    {
      if( ![NSBundle loadNibNamed: @"InfoPanel"
		     owner: self])
	{
	  NSLog(@"Problem loading info panel...");
	}

    }
  [infoPanel makeKeyAndOrderFront: self];
}
@end
